@@ -1,4 +1,4 @@
-# $Id: mvt.R 3955 2008-04-01 15:05:26Z hothorn $ 
+# $Id: mvt.R 187 2008-07-02 12:02:34Z thothorn $ 
 
 checkmvArgs <- function(lower, upper, mean, corr, sigma) 
 {
@@ -220,8 +220,8 @@ dmvt <- function(x, delta, sigma, df = 1, log = TRUE)
     if (NCOL(x) != NCOL(sigma)) {
         stop("x and sigma have non-conforming size")
     }
-    if (NROW(sigma) != NCOL(sigma)) {
-        stop("sigma must be a square matrix")
+    if (!isSymmetric(sigma)) {
+        stop("sigma must be a symmetric matrix")
     }
     if (length(delta) != NROW(sigma)) {
         stop("mean and sigma have non-conforming size")
